#!/usr/bin/env python

from __future__ import print_function
from osgeo import gdal
from affine import Affine
import sys

# CONUS tile extents - Albers conic projection
# tile-index        (in meters)
#   h   v       ulx/llx     uly/lly
#   0   0       -2565585    3314805
#   32  21       2384415      14805
#
# for the 4x4 grid, the llx/lly are 2834415 and -285195
# ...unless I have x and y backward...
# the numbers passed to xy2rc work, so *meh*

if len(sys.argv) != 2:
    print('Usage:')
    callseq = sys.argv[0] + ' full-CONUS-GeoTIFF'
    print(callseq)
    print('\nThis script generates 54 tiles in a 9x6 grid covering')
    print('\tthe CONUS')
    print('\tThe output tile names are based on the input file name with')
    print('\t_row_col.tif appended')
    sys.exit(1)

nXtiles = 9
nYtiles = 6

sourcefile = sys.argv[1]
sourcefilebase = sourcefile.rstrip('.tif')
#Open source dataset
srcDS = gdal.Open(sourcefile)
#Find our starting point
T0 = Affine.from_gdal(*srcDS.GetGeoTransform())
xy2rc = lambda xm, ym: (ym, xm) * ~T0

xoff,yoff = xy2rc(3314805,-2565585)
xoff = int(xoff)
yoff = int(yoff)
endx,endy = xy2rc(-285195,2834415)
endx = int(endx)
endy = int(endy)

xstride = int((endx-xoff)/nXtiles)
ystride = int((endy-yoff)/nYtiles)

for y in range(0,nYtiles):
    ytile = y + 1
    uly = y * ystride + yoff

    for x in range(0,nXtiles):
        xtile = x +1
        ulx = x * xstride + xoff
        srcwin = [ulx,uly,xstride,ystride]
        tileFile = sourcefilebase + '_' + str(xtile) + '_' + str(ytile) + '.tif'
        transop = gdal.TranslateOptions(creationOptions=['COMPRESS=LZW'],srcWin=srcwin)
        gdal.Translate(tileFile,srcDS, options=transop)
